==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translation>Loki in krogi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>V segmente črt (fiksne dolžine)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>V segmente črt (fiksen kot)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translation>V lomljenke iz segmentov lokov</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>V lomljenke iz segmentov črt</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Krivulje</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Kotiranja</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translation>V črte, telesa in besedila</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>Šrafure</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translation>V črte</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Bloke</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>V črte</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Razbij</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Razbij</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+133"/>
        <source>Spline segments:</source>
        <translation>Segmenti krivulj:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Segmenti elips (za cele elipse):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Spline approximation tolerance:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translation>Loki in krogi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>V segmente črt (fiksne dolžine)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>V segmente črt (fiksen kot)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translation>V lomljenke iz segmentov lokov</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>V lomljenke iz segmentov črt</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Krivulje</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Kotiranja</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translation>V črte, telesa in besedila</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>Šrafure</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translation>V črte</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Bloke</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>V črte</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Razbij</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Razbij</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+197"/>
        <source>Explode text glyphs to polylines</source>
        <translation>Razbij črke besedila v lomljenke </translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spline segments:</source>
        <translation>Segmenti krivulj:</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Segmenti elips (za cele elipse):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Explode splines to polylines with line segments</source>
        <translation>Razbij krivulje v lomljenke z črtnimi segmenti</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Explode multiline texts into multiple simple text blocks</source>
        <translation>Razbij večvrstična besedila v več preprostih besedilnih blokov </translation>
    </message>
    <message>
        <location line="-31"/>
        <source>Spline approximation tolerance:</source>
        <translation>Toleranca približka krivulje:</translation>
    </message>
</context>
</TS>
